@@ -16,7 +16,7 @@ from typing import Any, Dict, List, Type
 
 from botocore.client import ClientMeta
 
-from .literals import FederationMode
+from .literals import FederationModeType
 from .type_defs import (
     CreateEnvironmentResponseTypeDef,
     FederationParametersTypeDef,
@@ -51,7 +51,7 @@ class Exceptions:
 
 class finspaceClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/finspace.html#finspace.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/finspace.html#finspace.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -60,8 +60,8 @@ class finspaceClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/finspace.html#finspace.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/finspace.html#finspace.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def create_environment(
@@ -70,18 +70,18 @@ class finspaceClient:
         description: str = None,
         kmsKeyId: str = None,
         tags: Dict[str, str] = None,
-        federationMode: FederationMode = None,
+        federationMode: FederationModeType = None,
         federationParameters: "FederationParametersTypeDef" = None,
     ) -> CreateEnvironmentResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/finspace.html#finspace.Client.create_environment)
-        [Show boto3-stubs documentation](./client.md#create-environment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/finspace.html#finspace.Client.create_environment)
+        [Show boto3-stubs documentation](./client.md#create_environment)
         """
 
     def delete_environment(self, environmentId: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/finspace.html#finspace.Client.delete_environment)
-        [Show boto3-stubs documentation](./client.md#delete-environment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/finspace.html#finspace.Client.delete_environment)
+        [Show boto3-stubs documentation](./client.md#delete_environment)
         """
 
     def generate_presigned_url(
@@ -92,40 +92,40 @@ class finspaceClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/finspace.html#finspace.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/finspace.html#finspace.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def get_environment(self, environmentId: str) -> GetEnvironmentResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/finspace.html#finspace.Client.get_environment)
-        [Show boto3-stubs documentation](./client.md#get-environment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/finspace.html#finspace.Client.get_environment)
+        [Show boto3-stubs documentation](./client.md#get_environment)
         """
 
     def list_environments(
         self, nextToken: str = None, maxResults: int = None
     ) -> ListEnvironmentsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/finspace.html#finspace.Client.list_environments)
-        [Show boto3-stubs documentation](./client.md#list-environments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/finspace.html#finspace.Client.list_environments)
+        [Show boto3-stubs documentation](./client.md#list_environments)
         """
 
     def list_tags_for_resource(self, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/finspace.html#finspace.Client.list_tags_for_resource)
-        [Show boto3-stubs documentation](./client.md#list-tags-for-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/finspace.html#finspace.Client.list_tags_for_resource)
+        [Show boto3-stubs documentation](./client.md#list_tags_for_resource)
         """
 
     def tag_resource(self, resourceArn: str, tags: Dict[str, str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/finspace.html#finspace.Client.tag_resource)
-        [Show boto3-stubs documentation](./client.md#tag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/finspace.html#finspace.Client.tag_resource)
+        [Show boto3-stubs documentation](./client.md#tag_resource)
         """
 
     def untag_resource(self, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/finspace.html#finspace.Client.untag_resource)
-        [Show boto3-stubs documentation](./client.md#untag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/finspace.html#finspace.Client.untag_resource)
+        [Show boto3-stubs documentation](./client.md#untag_resource)
         """
 
     def update_environment(
@@ -133,10 +133,10 @@ class finspaceClient:
         environmentId: str,
         name: str = None,
         description: str = None,
-        federationMode: FederationMode = None,
+        federationMode: FederationModeType = None,
         federationParameters: "FederationParametersTypeDef" = None,
     ) -> UpdateEnvironmentResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/finspace.html#finspace.Client.update_environment)
-        [Show boto3-stubs documentation](./client.md#update-environment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/finspace.html#finspace.Client.update_environment)
+        [Show boto3-stubs documentation](./client.md#update_environment)
         """
