@@ -14,7 +14,7 @@ Usage::
 import sys
 from typing import Dict, List
 
-from .literals import EnvironmentStatus, FederationMode
+from .literals import EnvironmentStatusType, FederationModeType
 
 if sys.version_info >= (3, 8):
     from typing import TypedDict
@@ -48,14 +48,14 @@ EnvironmentTypeDef = TypedDict(
         "name": str,
         "environmentId": str,
         "awsAccountId": str,
-        "status": EnvironmentStatus,
+        "status": EnvironmentStatusType,
         "environmentUrl": str,
         "description": str,
         "environmentArn": str,
         "sageMakerStudioDomainUrl": str,
         "kmsKeyId": str,
         "dedicatedServiceAccountId": str,
-        "federationMode": FederationMode,
+        "federationMode": FederationModeType,
         "federationParameters": "FederationParametersTypeDef",
     },
     total=False,
